@@ -41,6 +41,10 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
+type Applier interface {
+	Apply(ctx context.Context, data []byte) error
+}
+
 // Addon is a wrapper around a single version of an addon
 type Addon struct {
 	Name            string
@@ -153,7 +157,7 @@ func (a *Addon) GetManifestFullUrl() (*url.URL, error) {
 	return manifestURL, nil
 }
 
-func (a *Addon) EnsureUpdated(ctx context.Context, k8sClient kubernetes.Interface, cmClient certmanager.Interface, pruner *Pruner, existingVersion *ChannelVersion) (*AddonUpdate, error) {
+func (a *Addon) EnsureUpdated(ctx context.Context, k8sClient kubernetes.Interface, cmClient certmanager.Interface, pruner *Pruner, applier Applier, existingVersion *ChannelVersion) (*AddonUpdate, error) {
 	required, err := a.GetRequiredUpdates(ctx, k8sClient, cmClient, existingVersion)
 	if err != nil {
 		return nil, err
@@ -165,7 +169,7 @@ func (a *Addon) EnsureUpdated(ctx context.Context, k8sClient kubernetes.Interfac
 	var merr error
 
 	if required.NewVersion != nil {
-		err := a.updateAddon(ctx, k8sClient, pruner, required)
+		err := a.updateAddon(ctx, k8sClient, pruner, applier, required)
 		if err != nil {
 			merr = multierr.Append(merr, err)
 		}
@@ -179,7 +183,7 @@ func (a *Addon) EnsureUpdated(ctx context.Context, k8sClient kubernetes.Interfac
 	return required, merr
 }
 
-func (a *Addon) updateAddon(ctx context.Context, k8sClient kubernetes.Interface, pruner *Pruner, required *AddonUpdate) error {
+func (a *Addon) updateAddon(ctx context.Context, k8sClient kubernetes.Interface, pruner *Pruner, applier Applier, required *AddonUpdate) error {
 	manifestURL, err := a.GetManifestFullUrl()
 	if err != nil {
 		return err
@@ -193,7 +197,7 @@ func (a *Addon) updateAddon(ctx context.Context, k8sClient kubernetes.Interface,
 		return fmt.Errorf("error reading manifest: %w", err)
 	}
 
-	if err := Apply(data); err != nil {
+	if err := applier.Apply(ctx, data); err != nil {
 		return fmt.Errorf("error applying update from %q: %w", manifestURL, err)
 	}
 
