@@ -20,8 +20,8 @@ import (
 	"fmt"
 	"strings"
 
+	aws "k8s.io/cloud-provider-aws/pkg/providers/v1"
 	"k8s.io/klog/v2"
-	"k8s.io/legacy-cloud-providers/aws"
 
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/upup/pkg/fi"
@@ -256,6 +256,15 @@ func (b *NetworkModelBuilder) Build(c *fi.ModelBuilderContext) error {
 			default:
 				klog.V(2).Infof("unable to properly tag subnet %q because it has unknown type %q. Load balancers may be created in incorrect subnets", subnetSpec.Name, subnetSpec.Type)
 			}
+
+			for _, ig := range b.InstanceGroups {
+				for _, igSubnetName := range ig.Spec.Subnets {
+					if subnetSpec.Name == igSubnetName {
+						tags["kops.k8s.io/instance-group/"+ig.GetName()] = "true"
+					}
+				}
+			}
+
 		} else {
 			klog.V(2).Infof("skipping subnet tags. Ensure these are maintained externally.")
 		}
