@@ -22,6 +22,7 @@ import (
 	"testing"
 
 	"k8s.io/kops/pkg/assets"
+	"k8s.io/kops/pkg/featureflag"
 	"k8s.io/kops/pkg/model"
 	"k8s.io/kops/pkg/model/iam"
 	"k8s.io/kops/pkg/testutils"
@@ -29,9 +30,10 @@ import (
 )
 
 func Test_RunEtcdManagerBuilder(t *testing.T) {
+	featureflag.ParseFlags("-ImageDigest")
 	tests := []string{
 		"tests/minimal",
-		"tests/pollinterval",
+		"tests/interval",
 		"tests/proxy",
 		"tests/overwrite_settings",
 	}
