@@ -76,28 +76,32 @@ func (b *KubeControllerManagerOptionsBuilder) BuildOptions(o interface{}) error
 	}
 
 	kcm.ClusterName = b.ClusterName
-	switch kops.CloudProviderID(clusterSpec.CloudProvider) {
-	case kops.CloudProviderAWS:
-		kcm.CloudProvider = "aws"
-
-	case kops.CloudProviderGCE:
-		kcm.CloudProvider = "gce"
-		kcm.ClusterName = gce.SafeClusterName(b.ClusterName)
-
-	case kops.CloudProviderDO:
+	if b.IsKubernetesGTE("1.24") {
 		kcm.CloudProvider = "external"
+	} else {
+		switch kops.CloudProviderID(clusterSpec.GetCloudProvider()) {
+		case kops.CloudProviderAWS:
+			kcm.CloudProvider = "aws"
 
-	case kops.CloudProviderOpenstack:
-		kcm.CloudProvider = "openstack"
+		case kops.CloudProviderGCE:
+			kcm.CloudProvider = "gce"
+			kcm.ClusterName = gce.SafeClusterName(b.ClusterName)
 
-	case kops.CloudProviderALI:
-		kcm.CloudProvider = "alicloud"
+		case kops.CloudProviderDO:
+			kcm.CloudProvider = "external"
 
-	case kops.CloudProviderAzure:
-		kcm.CloudProvider = "azure"
+		case kops.CloudProviderHetzner:
+			kcm.CloudProvider = "external"
 
-	default:
-		return fmt.Errorf("unknown cloudprovider %q", clusterSpec.CloudProvider)
+		case kops.CloudProviderOpenstack:
+			kcm.CloudProvider = "openstack"
+
+		case kops.CloudProviderAzure:
+			kcm.CloudProvider = "azure"
+
+		default:
+			return fmt.Errorf("unknown cloudprovider %q", clusterSpec.GetCloudProvider())
+		}
 	}
 
 	if clusterSpec.ExternalCloudControllerManager == nil {
@@ -108,7 +112,9 @@ func (b *KubeControllerManagerOptionsBuilder) BuildOptions(o interface{}) error
 		kcm.CloudProvider = "external"
 	}
 
-	kcm.LogLevel = 2
+	if kcm.LogLevel == 0 {
+		kcm.LogLevel = 2
+	}
 
 	image, err := Image("kube-controller-manager", clusterSpec, b.AssetBuilder)
 	if err != nil {
