@@ -42,6 +42,7 @@ fi
 
 export KOPS_BASE_URL
 export KOPS
+export CHANNELS
 
 export KOPS_FEATURE_FLAGS="SpecOverrideFlag"
 export KOPS_RUN_TOO_NEW_VERSION=1
@@ -91,9 +92,17 @@ function kops-download-from-base() {
     echo "${kops}"
 }
 
+function kops-channels-download-from-base() {
+    local channels
+    channels=$(mktemp -t channels.XXXXXXXXX)
+    wget -qO "${channels}" "$KOPS_BASE_URL/$(go env GOOS)/$(go env GOARCH)/channels"
+    chmod +x "${channels}"
+    echo "${channels}"
+}
+
 function kops-base-from-marker() {
     if [[ "${1}" =~ ^https: ]]; then
-        echo "${1}"
+        curl -s "${1}"
     elif [[ "${1}" == "latest" ]]; then
         curl -s "https://storage.googleapis.com/kops-ci/bin/latest-ci-updown-green.txt"
     else
@@ -106,12 +115,14 @@ function kops-acquire-latest() {
     if [[ "${JOB_TYPE-}" == "periodic" ]]; then
         KOPS_BASE_URL="$(curl -s https://storage.googleapis.com/kops-ci/bin/latest-ci-updown-green.txt)"
         KOPS=$(kops-download-from-base)
+        CHANNELS=$(kops-channels-download-from-base)
     else
          if [[ -n "${KOPS_BASE_URL-}" ]]; then
             KOPS_BASE_URL=""
          fi
          $KUBETEST2 --build
          KOPS="${REPO_ROOT}/.build/dist/linux/amd64/kops"
+         CHANNELS="${REPO_ROOT}/.build/dist/linux/amd64/channels"
          KOPS_BASE_URL=$(cat "${REPO_ROOT}/.kubetest2/kops-base-url")
          export KOPS_BASE_URL
          echo "KOPS_BASE_URL=$KOPS_BASE_URL"
@@ -137,5 +148,6 @@ function kops-up() {
         --kops-binary-path="${KOPS}" \
         --kubernetes-version="${K8S_VERSION}" \
         --create-args="${create_args}" \
+        --control-plane-size="${KOPS_CONTROL_PLANE_SIZE:-1}" \
         --template-path="${KOPS_TEMPLATE-}"
 }
\ No newline at end of file
