@@ -32,6 +32,7 @@ type ComputeClient interface {
 	Routes() RouteClient
 	ForwardingRules() ForwardingRuleClient
 	HTTPHealthChecks() HttpHealthChecksClient
+	RegionHealthChecks() RegionHealthChecksClient
 	Addresses() AddressClient
 	Firewalls() FirewallClient
 	Routers() RouterClient
@@ -40,6 +41,7 @@ type ComputeClient interface {
 	InstanceGroupManagers() InstanceGroupManagerClient
 	TargetPools() TargetPoolClient
 	Disks() DiskClient
+	RegionBackendServices() RegionBackendServiceClient
 }
 
 type computeClientImpl struct {
@@ -100,12 +102,24 @@ func (c *computeClientImpl) ForwardingRules() ForwardingRuleClient {
 	}
 }
 
+func (c *computeClientImpl) RegionBackendServices() RegionBackendServiceClient {
+	return &regionBackendServiceClientImpl{
+		srv: c.srv.RegionBackendServices,
+	}
+}
+
 func (c *computeClientImpl) HTTPHealthChecks() HttpHealthChecksClient {
 	return &httpHealthCheckClientImpl{
 		srv: c.srv.HttpHealthChecks,
 	}
 }
 
+func (c *computeClientImpl) RegionHealthChecks() RegionHealthChecksClient {
+	return &healthCheckClientImpl{
+		srv: c.srv.RegionHealthChecks,
+	}
+}
+
 func (c *computeClientImpl) Addresses() AddressClient {
 	return &addressClientImpl{
 		srv: c.srv.Addresses,
@@ -282,6 +296,45 @@ func (c *subnetworkClientImpl) List(ctx context.Context, project, region string)
 	return subnetworks, nil
 }
 
+// ===
+type RegionBackendServiceClient interface {
+	Insert(project, region string, fr *compute.BackendService) (*compute.Operation, error)
+	Delete(project, region, name string) (*compute.Operation, error)
+	Get(project, region, name string) (*compute.BackendService, error)
+	List(ctx context.Context, project, region string) ([]*compute.BackendService, error)
+}
+
+type regionBackendServiceClientImpl struct {
+	srv *compute.RegionBackendServicesService
+}
+
+var _ RegionBackendServiceClient = &regionBackendServiceClientImpl{}
+
+func (c *regionBackendServiceClientImpl) Insert(project, region string, fr *compute.BackendService) (*compute.Operation, error) {
+	return c.srv.Insert(project, region, fr).Do()
+}
+
+func (c *regionBackendServiceClientImpl) Delete(project, region, name string) (*compute.Operation, error) {
+	return c.srv.Delete(project, region, name).Do()
+}
+
+func (c *regionBackendServiceClientImpl) Get(project, region, name string) (*compute.BackendService, error) {
+	return c.srv.Get(project, region, name).Do()
+}
+
+func (c *regionBackendServiceClientImpl) List(ctx context.Context, project, region string) ([]*compute.BackendService, error) {
+	var hcs []*compute.BackendService
+	if err := c.srv.List(project, region).Pages(ctx, func(p *compute.BackendServiceList) error {
+		hcs = append(hcs, p.Items...)
+		return nil
+	}); err != nil {
+		return nil, err
+	}
+	return hcs, nil
+}
+
+// ===
+
 type RouteClient interface {
 	Delete(project, name string) (*compute.Operation, error)
 	List(ctx context.Context, project string) ([]*compute.Route, error)
@@ -344,6 +397,42 @@ func (c *forwardingRuleClientImpl) List(ctx context.Context, project, region str
 	return frs, nil
 }
 
+type RegionHealthChecksClient interface {
+	Insert(project, region string, fr *compute.HealthCheck) (*compute.Operation, error)
+	Delete(project, region, name string) (*compute.Operation, error)
+	Get(project, region, name string) (*compute.HealthCheck, error)
+	List(ctx context.Context, project, region string) ([]*compute.HealthCheck, error)
+}
+
+type healthCheckClientImpl struct {
+	srv *compute.RegionHealthChecksService
+}
+
+var _ RegionHealthChecksClient = &healthCheckClientImpl{}
+
+func (c *healthCheckClientImpl) Insert(project, region string, fr *compute.HealthCheck) (*compute.Operation, error) {
+	return c.srv.Insert(project, region, fr).Do()
+}
+
+func (c *healthCheckClientImpl) Delete(project, region, name string) (*compute.Operation, error) {
+	return c.srv.Delete(project, region, name).Do()
+}
+
+func (c *healthCheckClientImpl) Get(project, region, name string) (*compute.HealthCheck, error) {
+	return c.srv.Get(project, region, name).Do()
+}
+
+func (c *healthCheckClientImpl) List(ctx context.Context, project, region string) ([]*compute.HealthCheck, error) {
+	var hcs []*compute.HealthCheck
+	if err := c.srv.List(project, region).Pages(ctx, func(p *compute.HealthCheckList) error {
+		hcs = append(hcs, p.Items...)
+		return nil
+	}); err != nil {
+		return nil, err
+	}
+	return hcs, nil
+}
+
 type HttpHealthChecksClient interface {
 	Insert(project string, fr *compute.HttpHealthCheck) (*compute.Operation, error)
 	Delete(project, name string) (*compute.Operation, error)
@@ -658,6 +747,7 @@ type TargetPoolClient interface {
 	Delete(project, region, name string) (*compute.Operation, error)
 	Get(project, region, name string) (*compute.TargetPool, error)
 	List(ctx context.Context, project, region string) ([]*compute.TargetPool, error)
+	AddHealthCheck(project, region, name string, req *compute.TargetPoolsAddHealthCheckRequest) (*compute.Operation, error)
 }
 
 type targetPoolClientImpl struct {
@@ -678,6 +768,10 @@ func (c *targetPoolClientImpl) Get(project, region, name string) (*compute.Targe
 	return c.srv.Get(project, region, name).Do()
 }
 
+func (c *targetPoolClientImpl) AddHealthCheck(project, region, name string, req *compute.TargetPoolsAddHealthCheckRequest) (*compute.Operation, error) {
+	return c.srv.AddHealthCheck(project, region, name, req).Do()
+}
+
 func (c *targetPoolClientImpl) List(ctx context.Context, project, region string) ([]*compute.TargetPool, error) {
 	var tps []*compute.TargetPool
 	if err := c.srv.List(project, region).Pages(ctx, func(p *compute.TargetPoolList) error {
