@@ -93,16 +93,10 @@ func (e *FirewallRule) Run(c *fi.Context) error {
 func (e *FirewallRule) sanityCheck() error {
 	if !e.Disabled {
 		// Treat it as an error if SourceRanges _and_ SourceTags empty with Disabled=false
-		// this is interpreted as SourceRanges="0.0.0.0/0", which is likely what was intended.
+		// this is interpreted as SourceRanges="0.0.0.0/0", which is likely not what was intended.
 		if len(e.SourceRanges) == 0 && len(e.SourceTags) == 0 {
 			return fmt.Errorf("either SourceRanges or SourceTags should be specified when Disabled is false")
 		}
-	} else {
-		// Treat it as an error if SourceRanges/SourceTags non-empty with Disabled
-		// this is allowed but is likely not what was intended.
-		if len(e.SourceRanges) != 0 || len(e.SourceTags) != 0 {
-			return fmt.Errorf("setting Disabled=true overrules SourceRanges or SourceTags")
-		}
 	}
 
 	// Treat it as an error if SourceRanges _and_ SourceTags both set;
@@ -219,22 +213,22 @@ func (_ *FirewallRule) RenderGCE(t *gce.GCEAPITarget, a, e, changes *FirewallRul
 }
 
 type terraformAllow struct {
-	Protocol string   `json:"protocol,omitempty" cty:"protocol"`
-	Ports    []string `json:"ports,omitempty" cty:"ports"`
+	Protocol string   `cty:"protocol"`
+	Ports    []string `cty:"ports"`
 }
 
 type terraformFirewall struct {
-	Name    string                   `json:"name" cty:"name"`
-	Network *terraformWriter.Literal `json:"network" cty:"network"`
+	Name    string                   `cty:"name"`
+	Network *terraformWriter.Literal `cty:"network"`
 
-	Allowed []*terraformAllow `json:"allow,omitempty" cty:"allow"`
+	Allowed []*terraformAllow `cty:"allow"`
 
-	SourceTags []string `json:"source_tags,omitempty" cty:"source_tags"`
+	SourceTags []string `cty:"source_tags"`
 
-	SourceRanges []string `json:"source_ranges,omitempty" cty:"source_ranges"`
-	TargetTags   []string `json:"target_tags,omitempty" cty:"target_tags"`
+	SourceRanges []string `cty:"source_ranges"`
+	TargetTags   []string `cty:"target_tags"`
 
-	Disabled bool `json:"disabled,omitempty" cty:"disabled"`
+	Disabled bool `cty:"disabled"`
 }
 
 func (_ *FirewallRule) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *FirewallRule) error {
@@ -263,18 +257,7 @@ func (_ *FirewallRule) RenderTerraform(t *terraform.TerraformTarget, a, e, chang
 		Disabled:     g.Disabled,
 	}
 
-	// TODO: This doesn't seem right, but it looks like a TF problem
-	tf.Network = e.Network.TerraformName()
+	tf.Network = e.Network.TerraformLink()
 
 	return t.RenderResource("google_compute_firewall", *e.Name, tf)
 }
-
-// DisableIfEmptySourceRanges sets Disabled if SourceRanges is empty.
-// This is helpful because empty SourceRanges and SourceTags are interpreted as allow everything,
-// but the intent is usually to block everything, which can be achieved with Disabled=true.
-func (e *FirewallRule) DisableIfEmptySourceRanges() *FirewallRule {
-	if len(e.SourceRanges) == 0 {
-		e.Disabled = true
-	}
-	return e
-}
