@@ -18,7 +18,6 @@ package nodetasks
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path"
@@ -57,7 +56,7 @@ func (*AptSource) CheckChanges(a, e, changes *AptSource) error {
 }
 
 func (f *AptSource) RenderLocal(t *local.LocalTarget, a, e, changes *AptSource) error {
-	tmpDir, err := ioutil.TempDir("", "aptsource")
+	tmpDir, err := os.MkdirTemp("", "aptsource")
 	if err != nil {
 		return fmt.Errorf("error creating temp dir: %v", err)
 	}
